@@ -114,7 +114,7 @@ protected:
   virtual void on_document_modified(bool modified);
   
   ///override this to show document contents.
-  virtual void on_document_load();
+  virtual bool on_document_load();
 
 
   virtual void offer_to_save_changes();
@@ -129,15 +129,16 @@ protected:
  
   virtual void after_successful_save(); //e.g. disable File|Save.
 
-  virtual void ui_warning(const Glib::ustring& text) = 0;
+  virtual void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text) = 0;
   virtual Glib::ustring ui_file_select_open() = 0;
 
   /** Present a user interface that allows the user to select a location to save the file.
+   * @param The application to which the dialog will belong.
    * @param old_file_uri The existing URI of the file, if any.
    * @result The URI of the file chosen by the user.
    */
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri) = 0;
-  
+
   virtual void ui_show_modification_status() = 0;
 
   virtual enumSaveChanges ui_offer_to_save_changes() = 0;
