@@ -33,6 +33,10 @@ namespace Bakery
 {
 
 /** This class implements Bakery::App_WithDoc using gtkmm.
+ *
+ * Your application's installation should register your document's MIME-type in GNOME's (freedesktop's) MIME-type system,
+ * and register your application as capable of opening documents of that MIME-type.
+ * 
  *
  */
 class App_WithDoc_Gtk
@@ -63,7 +67,7 @@ protected:
 
   virtual void update_window_title();
 
-  virtual void ui_warning(const Glib::ustring& text);
+  virtual void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text);
   virtual Glib::ustring ui_file_select_open();
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri);
   virtual void ui_show_modification_status();
